@@ -473,6 +473,9 @@ pub fn create_output(config: &Config, found_params: Vec<String>) -> String {
 
             line
         },
+        "request" => {
+            generate_request(config, &make_hashmap(&found_params, config.value_size))
+        },
         _ => {
             let mut line = format!("{} {} % ", &config.method, &config.initial_url);
 
